@@ -72,7 +72,7 @@ module SiSU_TeX
   @@tex_pattern_margin_number=/\\\\begin\\\{tiny\\\}\\\\hspace\\\{0mm\\\}\\\\end\\\{tiny\\\}\\\{\\\\marginpar.+?\s+/
   @@n=@@tableheader=@@rights=nil
   @@date ||=SiSU_Env::Info_date.new
-  class Source #Songsheet #<SiSU_Param::MyFiles
+  class Source
     require 'pstore'
     require "#{SiSU_lib}/sysenv"                           # sysenv.rb
       include SiSU_Env
@@ -146,7 +146,7 @@ module SiSU_TeX
       end
     end
     private
-    class LaTeX_to_pdf #<Songsheet
+    class LaTeX_to_pdf
       require 'fileutils'
       include FileUtils #::Verbose
       @@n_lpdf||=0 #change
@@ -344,6 +344,7 @@ module SiSU_TeX
           elsif dob.is =='break'
             if dob.obj==Mx[:br_page]; dob.tmp='\newpage'
             elsif dob.obj==Mx[:br_page_new]; dob.tmp='\clearpage'
+            elsif dob.obj==Mx[:obj_ln_sep]; dob.tmp='\parasep'
             end
           elsif dob.is=='comment' \
           or dob.is=='meta'
@@ -571,6 +572,7 @@ module SiSU_TeX
 \\definecolor{Light}{gray}{.92}
 \\newcommand{\\Codeblock}[1]{\\normaltext\\raggedright\\small\\ttfamily\\texbackslash#1}
 \\newcommand{\\monosp}[1]{\\normaltext\\ttfamily\\texbackslash#1}
+\\newcommand{\\parasep}{\\\\ \\begin{center}*\\hspace{2em}*\\hspace{2em}*\\end{center} \\\\}
 % \\sloppy
 \\begin{document}
 WOK
