@@ -7,7 +7,7 @@
 
  * Author: Ralph Amissah
 
- * Copyright: (C) 1997 - 2010, Ralph Amissah, All Rights Reserved.
+ * Copyright: (C) 1997 - 2011, Ralph Amissah, All Rights Reserved.
 
  * License: GPL 3 or later:
 
@@ -65,6 +65,8 @@ module SiSU_TeX_Pdf
       @brace_url=SiSU_Viz::Skin.new.url_decoration
     end
     def bare_urls
+      @dob.obj.gsub!(/#{Mx[:url_o]}([a-zA-Z0-9._-]+\@\S+?\.[a-zA-Z0-9._-]+)#{Mx[:url_c]}/,
+        "#{@brace_url.tex_open}\\1</a>#{@brace_url.tex_close}")
       @dob.tmp.gsub!(/(^|[^\\])_/m,'\1\_') #watch may not work
       @dob.tmp.gsub!(/(^|[^#{Mx[:lnk_c]}])#{Mx[:url_o]}_?(?:\\?_)?(\S+?)#{Mx[:url_c]}/m,
         "\\1#{@brace_url.tex_open}\\begin{scriptsize}\\url{\\2}\\end{scriptsize}#{@brace_url.tex_close}")
@@ -417,7 +419,7 @@ module SiSU_TeX_Pdf
           map_nametags[url][:ocn]
         else nil
         end
-        ocn_lnk=(url=~/^\d+$/ ?  url : (map_nametags[url][:ocn]))
+        ocn_lnk=(url=~/^\d+$/ ?  url : ocn_lnk)
         if ocn_lnk and not ocn_lnk.empty?
           idx \
           ? (str.sub!(rgx_url_internal,"\\hyperlink{#{ocn_lnk}}{#{link}}")) \
@@ -970,7 +972,7 @@ WOK
       para_array=[]
       str=if word
         word.each do |w| # _ - / # | : ! ^ ~
-          if w !~/http:/ \
+          if w !~/https?:/ \
           and w=~/\/\S+?\// \
           and w.length > 6
             w.gsub!(/([_.\/])/,'\1\-')
