@@ -77,7 +77,7 @@ module SiSU_DAL
   require_relative 'dal_character_check'                # dal_character_check.rb
   require_relative 'dal_substitutions_and_insertions'   # dal_substitutions_and_insertions.rb
   require_relative 'dal_expand_insertions'              # dal_expand_insertions.rb
-  require_relative 'i18n'                               # i18n.rb
+  require_relative 'prog_text_translation'              # prog_text_translation.rb
   require_relative 'shared_sem'                         # shared_sem.rb
   class Instantiate < SiSU_Param::Parameters::Instructions
     def initialize
