@@ -85,13 +85,13 @@ module SiSU_EPUB
         @env=@particulars.env
         loc=@env.path.url.output_tell
         unless @opt.cmd =~/q/
-          tool=if @opt.cmd =~/[MVvz]/; "#{@env.program.epub_viewer} #{@md.file.output_path.epub}/#{@md.file.base_filename.epub}"
+          tool=if @opt.cmd =~/[MVvz]/; "#{@env.program.epub_viewer} #{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}"
           else                      @opt.fns
           end
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'EPUB',tool).green_hi_blue \
           : SiSU_Screen::Ansi.new(@opt.cmd,'EPUB',tool).green_title_hi
-          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@md.file.output_path.epub}/#{@md.file.base_filename.epub}").flow if @opt.cmd =~/[MV]/
+          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}").flow if @opt.cmd =~/[MV]/
         end
         @env.processing_path.epub_bld #(@md)
         @env.processing_path.epub_cp_images(@md)
@@ -310,7 +310,7 @@ module SiSU_EPUB
         title=if dob.obj !~/Document Information/; linkname
         else
           link='metadata'
-          %{<b><a href="#{@md.fnl[:pre]}#{link}#{@md.fnl[:mid]}#{Sfx[:epub_xhtml]}#{@md.fnl[:post]}">#{linkname}</a></b>}
+          %{<b><a href="#{link}#{@md.lang_code_insert}#{Sfx[:epub_xhtml]}">#{linkname}</a></b>}
         end
         toc={}
         txt_obj={ txt: title }
@@ -395,13 +395,13 @@ module SiSU_EPUB
         linkname,ocn=dob.obj.strip,dob.ocn
         p_num=SiSU_EPUB_Format::Paragraph_number.new(@md,ocn) if ocn
         if dob.ln==4
-          seg_link=%{  <a href="#{@md.fnl[:pre]}#{dob.name}#{@md.fnl[:mid]}#{Sfx[:epub_xhtml]}#{@md.fnl[:post]}">
+          seg_link=%{  <a href="#{dob.name}#{@md.lang_code_insert}#{Sfx[:epub_xhtml]}">
     #{dob.obj}
   </a> }
           @@seg_url=dob.name
         elsif dob.obj =~/\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+/
           seg_link=dob.obj.gsub(/^(\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+)(.*)/,
-            %{<a href="#{@md.fnl[:pre]}\\1#{@md.fnl[:mid]}#{Sfx[:epub_xhtml]}#{@md.fnl[:post]}">} +
+            %{<a href="\\1#{@md.lang_code_insert}#{Sfx[:epub_xhtml]}">} +
             %{\\1 \\2</a> })
         end
         p_num=SiSU_EPUB_Format::Paragraph_number.new(@md,ocn) if ocn
@@ -423,7 +423,7 @@ module SiSU_EPUB
         if ocn \
         and ocn !~/#/
           p_num=SiSU_EPUB_Format::Paragraph_number.new(@md,ocn)
-          lnk_n_txt=%{  <a href="#{@md.fnl[:pre]}#{@@seg_url}#{@md.fnl[:mid]}#{Sfx[:epub_xhtml]}#{@md.fnl[:post]}#o#{ocn}">
+          lnk_n_txt=%{  <a href="#{@@seg_url}#{@md.lang_code_insert}#{Sfx[:epub_xhtml]}#o#{ocn}">
     #{linkname}
   </a>}
           txt_obj={ txt: lnk_n_txt }
@@ -444,7 +444,7 @@ module SiSU_EPUB
         if ocn \
         and ocn !~/#/
           p_num=SiSU_EPUB_Format::Paragraph_number.new(@md,ocn)
-          lnk_n_txt=%{  <a href="#{@md.fnl[:pre]}#{@@seg_url}#{@md.fnl[:mid]}#{Sfx[:epub_xhtml]}#{@md.fnl[:post]}#o#{ocn}">
+          lnk_n_txt=%{  <a href="#{@@seg_url}#{@md.lang_code_insert}#{Sfx[:epub_xhtml]}#o#{ocn}">
   #{linkname}
 </a>}
           txt_obj={ txt: lnk_n_txt }
@@ -639,11 +639,11 @@ module SiSU_EPUB
         SiSU_EPUB_Concordance::Source.new(@md.opt).read
       end
       def output_zip
-        mkdir_p(@md.file.output_path.epub) unless FileTest.directory?(@md.file.output_path.epub)
+        mkdir_p(@md.file.output_path.epub.dir) unless FileTest.directory?(@md.file.output_path.epub.dir)
         system("
           cd #{@md.env.processing_path.epub}
           zip -qXr9D #{@epub_doc} *
-          mv #{@epub_doc} #{@md.file.place_file.epub}
+          mv #{@epub_doc} #{@md.file.place_file.epub.dir}
           cd #{Dir.pwd}
         ")
         unless @md.opt.cmd.inspect =~/M/
