@@ -652,10 +652,13 @@ WOK
           ## only works properly for directory_structure_by language, fix
           unless FileTest.file?("#{@file.output_path.html.dir}/index.html")
             pwd_set=Dir.pwd
+            idx_lnk=@file.base_filename.html_segtoc
+            mlnk='index.html'
             Dir.chdir(@file.output_path.html.dir)
-              system("
-                ln -s #{@file.base_filename.html_segtoc} index.html
-              ")
+            system("
+              rm #{mlnk}
+              ln -s #{idx_lnk} #{mlnk}
+            ")
             Dir.chdir(pwd_set)
           end
         end
