@@ -233,11 +233,11 @@ module SiSU_HTML_seg
                 dirout=SiSU_Env::Info_env.new(@md.fns)
                 dir_sisu=dirout.path.output
                 @file=SiSU_Env::SiSU_file.new(@md)
-                unless FileTest.directory?(@file.output_path.html_seg)
-                  mkdir_p(@file.output_path.html_seg) if File.writable?("#{@file.output_path.base}/.")
+                unless FileTest.directory?(@file.output_path.html_seg.dir)
+                  mkdir_p(@file.output_path.html_seg.dir) if File.writable?("#{@file.output_path.base.dir}/.")
                 end
                 Seg.new(@md).tail
-                segfilename="#{@file.output_path.html_seg}/#{@md.fnl[:pre]}#{@@seg_name_html[tracking-1]}#{@md.fnl[:mid]}#{Sfx[:html]}#{@md.fnl[:post]}"
+                segfilename="#{@file.output_path.html_seg.dir}/#{@@seg_name_html[tracking-1]}#{@md.lang_code_insert}#{Sfx[:html]}"
                 output_seg_file=File.new(segfilename,'w') if @@seg_name_html[tracking-1]
                 minitoc=(@env.html_minitoc?) \
                 ? @minitoc \
