@@ -290,13 +290,13 @@ p "here #{__FILE__} #{__LINE__}" if @opt =~/M/
       end
       if @opt.act[:harvest]
         require_relative 'harvest'                      # harvest.rb
+        SiSU_Harvest::Source.new(@opt).read             # -h -H  html.rb
       elsif @opt.mod.inspect =~/--convert|--to|--from/
         require_relative 'sst_convert_markup'           # sst_convert_markup.rb
       elsif @opt.cmd =~/([AabCcDdeFfGgHhIiJjkLMmNnOoPpQqRrSsTtUuVvwWXxYyZ_0-9])/ \
       and @opt.cmd =~/^-/ \
       and @opt.mod.inspect !~/--(?:sitemaps|query|identify)/ \
       or @opt.mod.inspect =~/--(?:(?:sq)?lite|pg(?:sql)?)/
-        @@tell=SiSU_Screen::Ansi.new(@opt.cmd)
         @cX=SiSU_Screen::Ansi.new(@opt.cmd).cX
         flag=SiSU_Env::Info_processing_flag.new
         if @opt.cmd =~/[vVM]/                              #% version information
