@@ -152,7 +152,7 @@ module SiSU_Manifest
         url=@f.output_path.base.url
         manifests={}
         mp,mn,mt,mr=nil,nil,nil,nil
-        ln=SiSU_i18n::Languages.new.list
+        ln=SiSU_i18n::Languages.new.language.list
         Px[:lng_lst].each do |lc|
           if @env.output_dir_structure.by_language_code?
             mp="#{@f.output_path.base.dir}/#{lc}/manifest"
