@@ -84,12 +84,12 @@ module SiSU_Plaintext
         unless @opt.cmd =~/q/
           path=env.path.output_tell
           tool=(@opt.cmd =~/[MVv]/) \
-          ? "#{env.program.text_editor} #{md.file.output_path.txt}/#{md.file.base_filename.txt}" \
+          ? "#{env.program.text_editor} #{md.file.output_path.txt.dir}/#{md.file.base_filename.txt}" \
           : @opt.fns
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'Plaintext',tool).green_hi_blue \
           : SiSU_Screen::Ansi.new(@opt.cmd,'Plaintext',tool).green_title_hi
-          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{md.file.output_path.txt}/#{md.file.base_filename.txt}").flow if @opt.cmd =~/[MV]/
+          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{md.file.output_path.txt.dir}/#{md.file.base_filename.txt}").flow if @opt.cmd =~/[MV]/
         end
         dal_array=SiSU_DAL::Source.new(@opt).get # dal file drawn here
         wrap_width=if defined? md.make.plaintext_wrap \
