@@ -249,11 +249,13 @@ module SiSU_TeX
                 "#{@md.fnb}.landscape.pdf"
               else 'landscape.pdf'
               end
+              pwd_set=Dir.pwd
+              Dir.chdir(@md.file.output_path.pdf.dir)
               system("
-                cd #{@md.file.output_path.pdf.dir}
                 rm #{mklnk}
                 ln -s #{pdf_l} #{mklnk}
               ")
+              Dir.chdir(pwd_set)
             end
           else
             SiSU_Screen::Ansi.new(@md.opt.cmd,"FILE NOT FOUND: << #{@md.fns} >> - requested latex system processing skipped").warn
